# coding: utf-8

# flake8: noqa

"""
    Mentortools Internal Sntegrations API

    Mentortools service for handling internal integrations

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.4+2585243276"

# Define package exports
__all__ = [
    "DefaultApi",
    "InternalIntegrationsApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AddNewStreamRecordingToModule",
    "AddTagsToPortalMemberRequest",
    "AddUserToGroupChat",
    "CreateOrderRequest",
    "HTTPValidationError",
    "PortalMember",
    "RemoveTagsFromPortalMemberRequest",
    "RemoveUserFromGroupChat",
    "ResponseWrapper",
    "ResponseWrapperBool",
    "ResponseWrapperInt",
    "Result",
    "SendMessageInGroupChat",
    "SendPersonalMessageToUser",
    "ValidationError",
    "ValidationErrorLocInner",
]

# import apis into sdk package
from internal_integration_handler_connector.api.default_api import DefaultApi as DefaultApi
from internal_integration_handler_connector.api.internal_integrations_api import InternalIntegrationsApi as InternalIntegrationsApi

# import ApiClient
from internal_integration_handler_connector.api_response import ApiResponse as ApiResponse
from internal_integration_handler_connector.api_client import ApiClient as ApiClient
from internal_integration_handler_connector.configuration import Configuration as Configuration
from internal_integration_handler_connector.exceptions import OpenApiException as OpenApiException
from internal_integration_handler_connector.exceptions import ApiTypeError as ApiTypeError
from internal_integration_handler_connector.exceptions import ApiValueError as ApiValueError
from internal_integration_handler_connector.exceptions import ApiKeyError as ApiKeyError
from internal_integration_handler_connector.exceptions import ApiAttributeError as ApiAttributeError
from internal_integration_handler_connector.exceptions import ApiException as ApiException

# import models into sdk package
from internal_integration_handler_connector.models.add_new_stream_recording_to_module import AddNewStreamRecordingToModule as AddNewStreamRecordingToModule
from internal_integration_handler_connector.models.add_tags_to_portal_member_request import AddTagsToPortalMemberRequest as AddTagsToPortalMemberRequest
from internal_integration_handler_connector.models.add_user_to_group_chat import AddUserToGroupChat as AddUserToGroupChat
from internal_integration_handler_connector.models.create_order_request import CreateOrderRequest as CreateOrderRequest
from internal_integration_handler_connector.models.http_validation_error import HTTPValidationError as HTTPValidationError
from internal_integration_handler_connector.models.portal_member import PortalMember as PortalMember
from internal_integration_handler_connector.models.remove_tags_from_portal_member_request import RemoveTagsFromPortalMemberRequest as RemoveTagsFromPortalMemberRequest
from internal_integration_handler_connector.models.remove_user_from_group_chat import RemoveUserFromGroupChat as RemoveUserFromGroupChat
from internal_integration_handler_connector.models.response_wrapper import ResponseWrapper as ResponseWrapper
from internal_integration_handler_connector.models.response_wrapper_bool import ResponseWrapperBool as ResponseWrapperBool
from internal_integration_handler_connector.models.response_wrapper_int import ResponseWrapperInt as ResponseWrapperInt
from internal_integration_handler_connector.models.result import Result as Result
from internal_integration_handler_connector.models.send_message_in_group_chat import SendMessageInGroupChat as SendMessageInGroupChat
from internal_integration_handler_connector.models.send_personal_message_to_user import SendPersonalMessageToUser as SendPersonalMessageToUser
from internal_integration_handler_connector.models.validation_error import ValidationError as ValidationError
from internal_integration_handler_connector.models.validation_error_loc_inner import ValidationErrorLocInner as ValidationErrorLocInner



# coding: utf-8

"""
    Mentortools Internal Sntegrations API

    Mentortools service for handling internal integrations

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr

class AddNewStreamRecordingToModule(BaseModel):
    """
    AddNewStreamRecordingToModule
    """
    portal_id: StrictInt = Field(...)
    parent_folder_id: Optional[StrictInt] = None
    thumbnail_file_id: Optional[StrictStr] = None
    module_id: StrictInt = Field(...)
    autopublish: StrictBool = Field(...)
    stream_download_url: StrictStr = Field(...)
    stream_download_headers: Dict[str, Any] = Field(...)
    __properties = ["portal_id", "parent_folder_id", "thumbnail_file_id", "module_id", "autopublish", "stream_download_url", "stream_download_headers"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AddNewStreamRecordingToModule:
        """Create an instance of AddNewStreamRecordingToModule from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AddNewStreamRecordingToModule:
        """Create an instance of AddNewStreamRecordingToModule from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AddNewStreamRecordingToModule.parse_obj(obj)

        _obj = AddNewStreamRecordingToModule.parse_obj({
            "portal_id": obj.get("portal_id"),
            "parent_folder_id": obj.get("parent_folder_id"),
            "thumbnail_file_id": obj.get("thumbnail_file_id"),
            "module_id": obj.get("module_id"),
            "autopublish": obj.get("autopublish"),
            "stream_download_url": obj.get("stream_download_url"),
            "stream_download_headers": obj.get("stream_download_headers")
        })
        return _obj


